================
Configuring Salt
================

This section explains how to configure user access, view and store job results,
secure and troubleshoot, and how to perform many other administrative tasks.

.. toctree::
    :maxdepth: 1

    ../../ref/configuration/master
    ../../ref/configuration/minion
    ../../ref/configuration/examples
    ../blackout/index
    ../eauth/access_control
    ../jobs/index
    ../jobs/job_cache
    ../jobs/external_cache
    ../../ref/configuration/logging/index
    ../../ref/file_server/index
    ../tutorials/gitfs
    ../tutorials/minionfs
    ../spm/index
    ../sdb/index
    ../../ref/configuration/nonroot
    ../tutorials/cron
    ../hardening
    ../../security/index
    ../transports/index
    ../master_tops/index
    ../../ref/returners/index
    ../../ref/renderers/index
